@@ -183,10 +183,14 @@ def face_detection(face_path):
     response_dict = json.loads(response.content)
     return response_dict
 
-def face_attribute(face_path, max_interval=configs.max_interval):
+def face_attribute(face_path, max_interval=configs.max_interval, version='none'):
     face_upload_url = configs.deepface_upload_url
     face_submit_url = configs.deepface_submit_url
     face_result_url = configs.deepface_result_url
+    if version == 'fsx':
+        face_upload_url = configs.deepface3_upload_url
+        face_submit_url = configs.deepface3_submit_url
+        face_result_url = configs.deepface3_result_url
     headers = {'Cookie': login_instance.cookie}
     with open(face_path, 'rb') as f1:
         filename1 = os.path.split(face_path)[-1]
